"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tokens = {
    breakpoints: {
        MOBILE: '640px',
        TABLET: '768px',
        LAPTOP: '1024px',
        DESKTOP: '1280px',
    },
    fontStyles: {
        FONT_STYLE_NORMAL: 'normal',
        FONT_STYLE_ITALIC: 'italic',
        FONT_STYLE_OBLIQUE: 'oblique',
    },
    size: {
        NONE: '0',
        FULL: '100%',
        SCREEN_WIDTH: '100vw',
        SCREEN_HEIGHT: '100vh',
        SIZE_10: '20rem',
        SIZE_20: '24rem',
        SIZE_30: '28rem',
        SIZE_40: '32rem',
        SIZE_50: '36rem',
        SIZE_60: '42rem',
        SIZE_70: '48rem',
        SIZE_80: '56rem',
        SIZE_90: '64rem',
        SIZE_100: '72rem',
    },
    fontWeights: {
        WEIGHT_10: '100',
        WEIGHT_20: '200',
        WEIGHT_30: '300',
        WEIGHT_40: '400',
        WEIGHT_50: '500',
        WEIGHT_60: '600',
        WEIGHT_70: '700',
        WEIGHT_80: '800',
        WEIGHT_90: '900',
    },
    space: {
        SPACE_PX: '1px',
        SPACE_0: '0',
        SPACE_10: '0.25rem',
        SPACE_20: '0.5rem',
        SPACE_30: '0.75rem',
        SPACE_40: '1rem',
        SPACE_50: '1.25rem',
        SPACE_60: '1.5rem',
        SPACE_70: '2rem',
        SPACE_80: '2.5rem',
        SPACE_90: '3rem',
        SPACE_100: '4rem',
        SPACE_110: '5rem',
        SPACE_120: '6rem',
        SPACE_130: '8rem',
        SPACE_140: '10rem',
        SPACE_150: '12rem',
        SPACE_160: '14rem',
        SPACE_170: '16rem',
    },
    colors: {
        TRANSPARENT: 'transparent',
        BLACK: '#000',
        WHITE: '#fff',
        GRAY_10: '#f7fafc',
        GRAY_20: '#edf2f7',
        GRAY_30: '#e2e8f0',
        GRAY_40: '#cbd5e0',
        GRAY_50: '#a0aec0',
        GRAY_60: '#718096',
        GRAY_70: '#4a5568',
        GRAY_80: '#2d3748',
        GRAY_90: '#1a202c',
        RED_10: '#fff5f5',
        RED_20: '#fed7d7',
        RED_30: '#feb2b2',
        RED_40: '#fc8181',
        RED_50: '#f56565',
        RED_60: '#e53e3e',
        RED_70: '#c53030',
        RED_80: '#9b2c2c',
        RED_90: '#742a2a',
        ORANGE_10: '#fffaf0',
        ORANGE_20: '#feebc8',
        ORANGE_30: '#fbd38d',
        ORANGE_40: '#f6ad55',
        ORANGE_50: '#ed8936',
        ORANGE_60: '#dd6b20',
        ORANGE_70: '#c05621',
        ORANGE_80: '#9c4221',
        ORANGE_90: '#7b341e',
        YELLOW_10: '#fffff0',
        YELLOW_20: '#fefcbf',
        YELLOW_30: '#faf089',
        YELLOW_40: '#f6e05e',
        YELLOW_50: '#ecc94b',
        YELLOW_60: '#d69e2e',
        YELLOW_70: '#b7791f',
        YELLOW_80: '#975a16',
        YELLOW_90: '#744210',
        GREEN_10: '#f0fff4',
        GREEN_20: '#c6f6d5',
        GREEN_30: '#9ae6b4',
        GREEN_40: '#68d391',
        GREEN_50: '#48bb78',
        GREEN_60: '#38a169',
        GREEN_70: '#2f855a',
        GREEN_80: '#276749',
        GREEN_90: '#22543d',
        TEAL_10: '#e6fffa',
        TEAL_20: '#b2f5ea',
        TEAL_30: '#81e6d9',
        TEAL_40: '#4fd1c5',
        TEAL_50: '#38b2ac',
        TEAL_60: '#319795',
        TEAL_70: '#2c7a7b',
        TEAL_80: '#285e61',
        TEAL_90: '#234e52',
        BLUE_10: '#ebf8ff',
        BLUE_20: '#bee3f8',
        BLUE_30: '#90cdf4',
        BLUE_40: '#63b3ed',
        BLUE_50: '#4299e1',
        BLUE_60: '#3182ce',
        BLUE_70: '#2b6cb0',
        BLUE_80: '#2c5282',
        BLUE_90: '#2a4365',
        INDIGO_10: '#ebf4ff',
        INDIGO_20: '#c3dafe',
        INDIGO_30: '#a3bffa',
        INDIGO_40: '#7f9cf5',
        INDIGO_50: '#667eea',
        INDIGO_60: '#5a67d8',
        INDIGO_70: '#4c51bf',
        INDIGO_80: '#434190',
        INDIGO_90: '#3c366b',
        PURPLE_10: '#faf5ff',
        PURPLE_20: '#e9d8fd',
        PURPLE_30: '#d6bcfa',
        PURPLE_40: '#b794f4',
        PURPLE_50: '#9f7aea',
        PURPLE_60: '#805ad5',
        PURPLE_70: '#6b46c1',
        PURPLE_80: '#553c9a',
        PURPLE_90: '#44337a',
        PINK_10: '#fff5f7',
        PINK_20: '#fed7e2',
        PINK_30: '#fbb6ce',
        PINK_40: '#f687b3',
        PINK_50: '#ed64a6',
        PINK_60: '#d53f8c',
        PINK_70: '#b83280',
        PINK_80: '#97266d',
        PINK_90: '#702459',
    },
    fonts: {
        FONT_SANS: "" + [
            'Inter',
            'apple-system',
            'BlinkMacSystemFont',
            '"Segoe UI"',
            'Roboto',
            '"Helvetica Neue"',
            'Arial',
            '"Noto Sans"',
            'sans-serif',
            '"Apple Color Emoji"',
            '"Segoe UI Emoji"',
            '"Segoe UI Symbol"',
            '"Noto Color Emoji"',
        ].join(', '),
        FONT_SERIF: "" + ['Georgia', 'Cambria', '"Times New Roman"', 'Times', 'serif'].join(','),
        FONT_MONO: "" + ['Menlo', 'Monaco', 'Consolas', '"Liberation Mono"', '"Courier New"', 'monospace'].join(','),
    },
    borderWidths: {
        WIDTH_0: '0',
        WIDTH_1: '1px',
        WIDTH_2: '2px',
        WIDTH_4: '4px',
        WIDTH_8: '8px',
    },
    letterSpacings: {
        SPACING_10: '-0.05em',
        SPACING_20: '-0.025em',
        SPACING_30: '0',
        SPACING_40: '0.025em',
        SPACING_50: '0.05em',
        SPACING_60: '0.1em',
    },
    radii: {
        RADIUS_0: '0',
        RADIUS_10: '.125rem',
        RADIUS_20: '.25rem',
        RADIUS_30: '.5rem',
        RADIUS_FULL: '9999px',
    },
    lineHeights: {
        HEIGHT_10: '1',
        HEIGHT_20: '1.25',
        HEIGHT_30: '1.375',
        HEIGHT_40: '1.5',
        HEIGHT_50: '1.625',
        HEIGHT_60: '2',
    },
    shadows: {
        SHADOW_10: '0 0 0 1px rgba(0, 0, 0, 0.05)',
        SHADOW_20: '0 1px 2px 0 rgba(0, 0, 0, 0.05)',
        SHADOW_30: '0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06)',
        SHADOW_40: '0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06)',
        SHADOW_50: '0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05)',
        SHADOW_60: '0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04)',
        SHADOW_70: '0 25px 50px -12px rgba(0, 0, 0, 0.25)',
        SHADOW_INNER: 'inset 0 2px 4px 0 rgba(0, 0, 0, 0.06)',
        SHADOW_OUTLINE: '0 0 0 3px rgba(66, 153, 225, 0.5)',
        SHADOW_NONE: 'none',
    },
    zIndices: {
        Z_0: '0',
        Z_1: '1',
        Z_2: '2',
        Z_3: '3',
        Z_4: '4',
        Z_5: '5',
        Z_6: '6',
        Z_7: '7',
        Z_8: '8',
        Z_9: '9',
    },
    opacity: {
        OPACITY_0: '0',
        OPACITY_25: '0.25',
        OPACITY_50: '0.5',
        OPACITY_75: '0.75',
        OPACITY_FULL: '1',
    },
    durations: {
        DURATION_10: '75ms',
        DURATION_20: '100ms',
        DURATION_30: '150ms',
        DURATION_40: '200ms',
        DURATION_50: '300ms',
        DURATION_60: '500ms',
        DURATION_70: '700ms',
        DURATION_80: '1000ms',
    },
    timingFunctions: {
        LINEAR: 'linear',
        IN: 'cubic-bezier(0.4, 0, 1, 1)',
        OUT: 'cubic-bezier(0, 0, 0.2, 1)',
        IN_OUT: 'cubic-bezier(0.4, 0, 0.2, 1)',
    },
    fontSizes: {
        SIZE_10: '0.75rem',
        SIZE_20: '0.875rem',
        SIZE_30: '1rem',
        SIZE_40: '1.125rem',
        SIZE_50: '1.25rem',
        SIZE_60: '1.5rem',
        SIZE_70: '1.875rem',
        SIZE_80: '2.25rem',
        SIZE_90: '3rem',
        SIZE_100: '4rem',
    },
    gridColumns: {
        AUTO: 'auto',
        SPAN_1: 'span 1',
        SPAN_2: 'span 2',
        SPAN_3: 'span 3',
        SPAN_4: 'span 4',
        SPAN_5: 'span 5',
        SPAN_6: 'span 6',
        SPAN_7: 'span 7',
        SPAN_8: 'span 8',
        SPAN_9: 'span 9',
        SPAN_10: 'span 10',
        SPAN_11: 'span 11',
        SPAN_12: 'span 12',
    },
    gridTemplateColumns: {
        COLUMNS_NONE: 'none',
        COLUMNS_1: 'repeat(1, minmax(0, 1fr))',
        COLUMNS_2: 'repeat(2, minmax(0, 1fr))',
        COLUMNS_3: 'repeat(3, minmax(0, 1fr))',
        COLUMNS_4: 'repeat(4, minmax(0, 1fr))',
        COLUMNS_5: 'repeat(5, minmax(0, 1fr))',
        COLUMNS_6: 'repeat(6, minmax(0, 1fr))',
        COLUMNS_7: 'repeat(7, minmax(0, 1fr))',
        COLUMNS_8: 'repeat(8, minmax(0, 1fr))',
        COLUMNS_9: 'repeat(9, minmax(0, 1fr))',
        COLUMNS_10: 'repeat(10, minmax(0, 1fr))',
        COLUMNS_11: 'repeat(11, minmax(0, 1fr))',
        COLUMNS_12: 'repeat(12, minmax(0, 1fr))',
    },
    flex: {
        FLEX_0: '0',
        FLEX_10: '1',
        FLEX_20: '2',
        FLEX_30: '3',
        FLEX_40: '4',
        FLEX_50: '5',
        FLEX_60: '6',
        FLEX_70: '7',
        FLEX_80: '8',
        FLEX_90: '8',
        FLEX_100: '10',
        FLEX_110: '11',
        FLEX_120: '12',
    },
};
exports.default = tokens;
//# sourceMappingURL=tokens.js.map