"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var helper_module_imports_1 = require("@babel/helper-module-imports");
var autoprefixer_1 = tslib_1.__importDefault(require("autoprefixer"));
var clean_css_1 = tslib_1.__importDefault(require("clean-css"));
var fs_1 = require("fs");
var path_1 = require("path");
var postcss_1 = tslib_1.__importDefault(require("postcss"));
var transform_classes_to_types_1 = require("../config/transform-classes-to-types");
var transform_config_to_classes_1 = require("../config/transform-config-to-classes");
var utils_1 = require("../utils");
var config = utils_1.evaluateConfig(utils_1.getUserConfig());
var classes = transform_config_to_classes_1.transform(config);
if (process.env.NODE_ENV !== 'test') {
    try {
        var rootPath = path_1.join(process.cwd(), 'classy-ui.d.ts');
        var libPath = path_1.join(__dirname, '..', '..', 'lib', 'classy-ui.d.ts');
        var types = transform_classes_to_types_1.transform(config);
        fs_1.writeFileSync(rootPath, "\ndeclare module 'classy-ui' {\n" + types + "\n}\ndeclare module 'classy-ui/macro' {\n  export * from 'classy-ui'\n}\n");
        fs_1.writeFileSync(libPath, types);
    }
    catch (_a) {
        // Codesandbox or some other unwritable environment
    }
}
exports.default = (function (babel) {
    var t = babel.types;
    return {
        name: 'classy-ui/plugin',
        visitor: {
            Program: function (programmPath, state) {
                programmPath.traverse({
                    ImportDeclaration: function (path) {
                        var _a, _b;
                        if (((_b = (_a = path === null || path === void 0 ? void 0 : path.node) === null || _a === void 0 ? void 0 : _a.source) === null || _b === void 0 ? void 0 : _b.value) === 'classy-ui') {
                            var imports = path
                                .get('specifiers')
                                .filter(function (s) {
                                if (!t.isImportSpecifier(s.node)) {
                                    throw s.buildCodeFrameError("This style of importing isn't allowed.");
                                }
                                return true;
                            })
                                .map(function (s) { return ({ local: s.node.local.name, name: s.node.imported.name }); });
                            var referencePaths = imports.reduce(function (aggr, _a) {
                                var local = _a.local, name = _a.name;
                                var binding = path.scope.getBinding(local);
                                if (binding && Boolean(binding.referencePaths.length)) {
                                    aggr[name] = binding.referencePaths;
                                }
                                return aggr;
                            }, {});
                            processReferences(babel, state, referencePaths);
                            path.remove();
                        }
                    },
                });
            },
        },
    };
});
var hasRegisteredExitHook = false;
exports.productionClassesByType = {
    screens: {},
    common: {},
    themeTokens: {},
    rootTokens: {},
};
/*
  This can be improved by rather structuring classnames as unique with tokens
  and decorators underneath. So that A__A (color__RED) and B__A (background-color__RED)
  can live together
*/
exports.evaluatedProductionShortnames = {
    classnames: [],
    tokens: [],
    decorators: [],
};
function processReferences(babel, state, refs) {
    var t = babel.types;
    var filePath = state.file.opts.parserOpts.sourceFileName;
    var isProduction = babel.getEnv() === 'production';
    var classCollection = {};
    if (refs.tokens) {
        processTokens(refs.tokens, isProduction);
    }
    if (refs.group) {
        processGroup(refs.group);
    }
    if (refs.themes) {
        processThemes(refs.themes);
    }
    Object.keys(config.screens).forEach(function (screenCompose) {
        if (refs[screenCompose]) {
            // Process as compose but don't allow variables here
            processCompose(refs[screenCompose], false);
        }
    });
    if (refs.compose) {
        processCompose(refs.compose);
    }
    // We require access to the babel options, so have to do it here
    if (isProduction && !hasRegisteredExitHook) {
        hasRegisteredExitHook = true;
        process.on('exit', function () {
            fs_1.writeFileSync(path_1.join(process.cwd(), state.opts.output || 'build', 'classy-ui.css'), new clean_css_1.default().minify(postcss_1.default([autoprefixer_1.default]).process(utils_1.createProductionCss(exports.productionClassesByType, config)).css)
                .styles);
        });
    }
    if (isProduction && filePath) {
        utils_1.injectProduction(exports.productionClassesByType, classCollection, classes, config);
    }
    else {
        var runtimeCall = t.expressionStatement(t.callExpression(helper_module_imports_1.addNamed(state.file.path, 'addClasses', 'classy-ui/runtime'), [
            t.arrayExpression(utils_1.injectDevelopment(classCollection, classes, config).map(function (value) { return t.stringLiteral(value); })),
        ]));
        state.file.ast.program.body.push(runtimeCall);
    }
    function processCompose(cRefs, allowDynamicValuesInExpression) {
        if (allowDynamicValuesInExpression === void 0) { allowDynamicValuesInExpression = true; }
        cRefs.forEach(function (path) {
            if (t.isCallExpression(path.parentPath.parent)) {
                var b = path.scope.getBinding(path.parent.callee.name);
                if (t.isImportSpecifier(b.path.node) &&
                    b.path.parent.source.value.startsWith('classy-ui') &&
                    b.identifier.name === 'compose') {
                    throw path.buildCodeFrameError("CLASSY-UI: don't nest c/compose calls");
                }
            }
            var statementPath = path.parentPath;
            var args = statementPath.get('arguments');
            statementPath.replaceWith(convertToExpression(args, allowDynamicValuesInExpression));
        });
    }
    function processTokens(tRefs, isProductionProcess) {
        tRefs.forEach(function (tRef) {
            if (!t.isMemberExpression(tRef.parent)) {
                throw tRef.buildCodeFrameError("CLASSY-UI: t/tokens can't be used without a base class");
            }
            var callExpr = tRef.findParent(function (p) { return t.isCallExpression(p); });
            if (!callExpr) {
                throw tRef.buildCodeFrameError("CLASSY-UI: t/tokens must be used inside a compose/screen function");
            }
            var composition = callExpr.node.callee.name;
            var memExpr = extractMemberExpression(tRef);
            if (memExpr.arr.length >= 2) {
                try {
                    var _a = tslib_1.__read(memExpr.arr), baseClass = _a[0], token = _a[1], decorators = _a.slice(2);
                    var classObjects = isProductionProcess
                        ? utils_1.createProductionClassObjects({ composition: composition, baseClass: baseClass, token: token, decorators: decorators }, classes, exports.evaluatedProductionShortnames)
                        : utils_1.createClassObjects({ composition: composition, baseClass: baseClass, token: token, decorators: decorators }, classes);
                    classObjects.forEach(collectGlobally);
                    memExpr.root.replaceWith(t.stringLiteral(classObjects.map(function (classObject) { return classObject.name; }).join(' ') + " "));
                }
                catch (e) {
                    throw memExpr.root.buildCodeFrameError("CLASSY-UI: " + e.message);
                }
            }
            else {
                throw tRef.buildCodeFrameError("CLASSY-UI: t/tokens must reference a base class and a token");
            }
            return tRef;
        });
    }
    function processGroup(processRefs) {
        processRefs.forEach(function (ref) {
            if (!t.isCallExpression(ref.parent)) {
                throw ref.buildCodeFrameError("CLASSY-UI: group must be used inside c/compose");
            }
            if (ref.parent.callee === ref.node) {
                throw ref.buildCodeFrameError("CLASSY-UI: group should not be invoked");
            }
            ref.replaceWith(t.stringLiteral(ref.node.name + " "));
        });
    }
    function processThemes(processRefs) {
        processRefs.forEach(function (ref) {
            if (t.isMemberExpression(ref.parent)) {
                var memberExpr = extractMemberExpression(ref);
                memberExpr.root.replaceWith(t.stringLiteral(ref.node.name + "-" + memberExpr.arr.join('-') + " "));
            }
            else {
                throw ref.buildCodeFrameError("CLASSY-UI: add the theme name here like themes.dark");
            }
        });
    }
    function convertToExpression(classAttribs, allowDynamicValuesInExpression) {
        var e_1, _a;
        if (allowDynamicValuesInExpression === void 0) { allowDynamicValuesInExpression = true; }
        if (classAttribs.length === 0) {
            return t.stringLiteral(' ');
        }
        var needsRuntime = false;
        var strings = [];
        var others = [];
        try {
            for (var classAttribs_1 = tslib_1.__values(classAttribs), classAttribs_1_1 = classAttribs_1.next(); !classAttribs_1_1.done; classAttribs_1_1 = classAttribs_1.next()) {
                var itemPath = classAttribs_1_1.value;
                if (t.isStringLiteral(itemPath.node)) {
                    strings.push(itemPath.node.value);
                }
                else if (allowDynamicValuesInExpression) {
                    needsRuntime = true;
                    if (t.isLogicalExpression(itemPath.node) && itemPath.node.operator === '&&') {
                        others.push(t.conditionalExpression(itemPath.node.left, itemPath.node.right, t.stringLiteral(' ')));
                    }
                    else {
                        others.push(itemPath.node);
                    }
                }
                else {
                    throw itemPath.buildCodeFrameError("CLASSY-UI: using dynamic values isn't allowed here");
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (classAttribs_1_1 && !classAttribs_1_1.done && (_a = classAttribs_1.return)) _a.call(classAttribs_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        // if there are only string literals just return them. This is a _short path_
        if (strings.length > 0 && others.length === 0) {
            return t.stringLiteral(strings.join(''));
        }
        var max;
        var start;
        if (strings.length === 0) {
            if (needsRuntime) {
                return t.callExpression(helper_module_imports_1.addNamed(state.file.path, 'fixSpecificity', 'classy-ui/runtime'), others);
            }
            else {
                max = others.length - 1;
                start = others[max];
                for (var i = max - 1; i >= 0; i--) {
                    start = t.binaryExpression('+', others[i], start);
                }
                return start;
            }
        }
        if (needsRuntime) {
            return t.callExpression(helper_module_imports_1.addNamed(state.file.path, 'fixSpecificity', 'classy-ui/runtime'), tslib_1.__spread(others, [
                t.stringLiteral(strings.join('').trim()),
            ]));
        }
        max = others.length - 1;
        start = others[max];
        for (var i = max - 1; i >= 0; i--) {
            start = t.binaryExpression('+', others[i], start);
        }
        return t.binaryExpression('+', start, t.stringLiteral(strings.join('')));
    }
    function collectGlobally(classObj) {
        if (!classCollection[classObj.composition]) {
            classCollection[classObj.composition] = {};
        }
        classCollection[classObj.composition][classObj.id] = classObj;
    }
    function extractMemberExpression(tRefPath) {
        var prev = tRefPath;
        var path = prev.parentPath;
        var arr = [];
        while (path.node.type === 'MemberExpression') {
            if (path.node.property) {
                arr.push(path.node.property.name);
            }
            prev = path;
            path = path.parentPath;
        }
        return {
            root: prev,
            arr: arr,
        };
    }
}
exports.processReferences = processReferences;
//# sourceMappingURL=index.js.map