"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var path_1 = require("path");
// @ts-ignore
var reduce_css_calc_1 = tslib_1.__importDefault(require("reduce-css-calc"));
var classnames_1 = tslib_1.__importDefault(require("./config/classnames"));
var screens_1 = tslib_1.__importDefault(require("./config/screens"));
var tokens_1 = tslib_1.__importDefault(require("./config/tokens"));
exports.allowedPseudoDecorators = [
    'hover',
    'focus',
    'active',
    'disabled',
    'visited',
    'firstChild',
    'lastChild',
    'oddChild',
    'evenChild',
    'focusWithin',
];
exports.getClassesFromConfig = function (classnameKey, config) {
    var classname = config.classnames[classnameKey];
    return Object.keys(classname.tokens).reduce(function (aggr, tokenKey) {
        var _a;
        var id = exports.camelToDash(classnameKey) + "-" + tokenKey;
        var cssDeriver = config.classnames[classnameKey].css;
        return tslib_1.__assign(tslib_1.__assign({}, aggr), (_a = {}, _a[id] = {
            id: id,
            classname: classnameKey,
            token: tokenKey,
            derived: Array.isArray(cssDeriver) ? cssDeriver : null,
            variable: classname.tokens[tokenKey] !== classname.tokensWithoutVariables[tokenKey]
                ? {
                    value: classname.tokens[tokenKey].value,
                    originalValue: classname.tokensWithoutVariables[tokenKey].value,
                }
                : null,
        }, _a));
    }, {});
};
exports.deepAssign = function (a, b) {
    Object.keys(b).forEach(function (key) {
        if (!a[key]) {
            a[key] = {};
        }
        Object.keys(b[key]).forEach(function (subKey) {
            a[key][subKey] = b[key][subKey];
        });
    });
    return a;
};
var getCategoryTokens = function (config, category) {
    var rawTokens = config.tokens && config.tokens[category]
        ? config.tokens[category]
        : config.tokens
            ? {}
            : tokens_1.default[category];
    return Object.keys(rawTokens).reduce(function (categoryTokens, tokenKey) {
        categoryTokens[tokenKey] =
            typeof rawTokens[tokenKey] === 'string'
                ? {
                    value: rawTokens[tokenKey],
                }
                : rawTokens[tokenKey];
        return categoryTokens;
    }, {});
};
exports.evaluateConfig = function (config) {
    var originalTokens = Object.keys(tokens_1.default).reduce(function (currentTokens, category) {
        currentTokens[category] = getCategoryTokens(config, category);
        return currentTokens;
    }, {});
    // Reverse themes lookup to tokens instead
    var configThemes = config.themes || {};
    var themesByTokens = Object.keys(configThemes).reduce(function (aggr, themeKey) {
        Object.keys(configThemes[themeKey]).forEach(function (tokenKey) {
            if (!aggr[tokenKey]) {
                aggr[tokenKey] = {};
            }
            Object.keys(configThemes[themeKey][tokenKey]).forEach(function (valueKey) {
                if (!aggr[tokenKey][valueKey]) {
                    aggr[tokenKey][valueKey] = {};
                }
                aggr[tokenKey][valueKey][themeKey] = configThemes[themeKey][tokenKey][valueKey];
            });
        });
        return aggr;
    }, {});
    // Evaluated variables where values are replaced by CSS variable
    var tokens = Object.keys(originalTokens).reduce(function (currentTokens, categoryKey) {
        currentTokens[categoryKey] = Object.keys(originalTokens[categoryKey]).reduce(function (categoryTokens, tokenKey) {
            categoryTokens[tokenKey] = tslib_1.__assign(tslib_1.__assign({}, originalTokens[categoryKey][tokenKey]), { value: themesByTokens[categoryKey] && themesByTokens[categoryKey][tokenKey]
                    ? "var(--" + categoryKey + "-" + tokenKey + ")"
                    : originalTokens[categoryKey][tokenKey].value });
            return categoryTokens;
        }, {});
        return currentTokens;
    }, {});
    // Call any dynamic classname tokens with both the original variables and
    // the ones who have been evaluated with CSS variables
    var evaluatedClassnames = Object.keys(classnames_1.default).reduce(function (aggr, key) {
        aggr[key] = tslib_1.__assign(tslib_1.__assign({}, classnames_1.default[key]), { tokensWithoutVariables: typeof classnames_1.default[key].tokens === 'function'
                ? classnames_1.default[key].tokens(originalTokens, { negative: exports.negative })
                : classnames_1.default[key].tokens, tokens: typeof classnames_1.default[key].tokens === 'function'
                ? classnames_1.default[key].tokens(tokens, { negative: exports.negative })
                : classnames_1.default[key].tokens, description: classnames_1.default[key].description });
        return aggr;
    }, {});
    return {
        tokens: tokens,
        screens: config.screens || screens_1.default,
        classnames: evaluatedClassnames,
        themes: themesByTokens,
        themeNames: Object.keys(config.themes || {}),
    };
};
exports.getUserConfig = function () {
    try {
        var config = require(path_1.join(process.cwd(), 'classy-ui.config.js'));
        if (typeof config === 'function') {
            return config({ tokens: tokens_1.default, screens: screens_1.default });
        }
        else {
            return config;
        }
    }
    catch (error) {
        if (!error.toString().includes('Cannot find module')) {
            // tslint:disable-next-line
            throw error;
        }
        return {};
    }
};
exports.getScreens = function (config) {
    return Object.keys(config.tokens.breakpoints).reduce(function (breakAggr, key) {
        breakAggr[key] = config.tokens.breakpoints[key].value;
        return breakAggr;
    }, {});
};
exports.createProductionCss = function (productionClassesByType, config) {
    var css = Object.keys(productionClassesByType.common).reduce(function (aggr, name) { return aggr + productionClassesByType.common[name]; }, '');
    var screenKeys = Object.keys(productionClassesByType.screens);
    screenKeys.forEach(function (screen) {
        if (productionClassesByType.screens[screen].length) {
            var screenCss = productionClassesByType.screens[screen].reduce(function (aggr, classCss) {
                return aggr + classCss;
            }, '');
            css += config.screens[screen](screenCss, exports.getScreens(config));
        }
    });
    var variableKeys = Object.keys(productionClassesByType.rootTokens);
    if (variableKeys.length) {
        css += ':root{';
        variableKeys.forEach(function (key) {
            css += key + ":" + productionClassesByType.rootTokens[key] + ";";
        });
        css += '}';
    }
    Object.keys(productionClassesByType.themeTokens).forEach(function (theme) {
        var variables = Object.keys(productionClassesByType.themeTokens[theme]).reduce(function (aggr, variableKey) { return "" + aggr + productionClassesByType.themeTokens[theme][variableKey]; }, '');
        css += ".themes-" + theme + "{" + variables + "}";
    });
    return css;
};
exports.camelToDash = function (str) {
    return str
        .replace(/[\w]([A-Z])/g, function (m) {
        return m[0] + "-" + m[1];
    })
        .toLowerCase();
};
exports.createClassEntry = function (name, decorators, css) {
    var groupDecorators = decorators
        .filter(function (decorator) { return decorator.startsWith('group') && decorator !== 'group'; })
        .map(function (decorator) { return exports.camelToDash(decorator.substr(5)); });
    var pseudoDecorators = decorators
        .filter(function (decorator) { return exports.allowedPseudoDecorators.includes(decorator); })
        .map(function (decorator) { return exports.camelToDash(decorator); });
    var evaluatedName = "." + name.replace(/\:/g, '\\:') + (pseudoDecorators.length ? ":" + pseudoDecorators.join(':') : '');
    return "" + (groupDecorators.length ? ".group:" + groupDecorators.join(':') + " " : '') + css(evaluatedName);
};
exports.flat = function (array) { return array.reduce(function (aggr, item) { return aggr.concat(item); }, []); };
exports.injectProduction = function (productionClassesByType, classCollection, classes, config) {
    Object.keys(classCollection).forEach(function (composition) {
        Object.keys(classCollection[composition]).forEach(function (id) {
            var extractedClass = classCollection[composition][id];
            var evaluatedClass = classes[extractedClass.id];
            var configClass = config.classnames[evaluatedClass.classname];
            var classEntry = exports.createClassEntry(extractedClass.name, extractedClass.decorators, function (evaluatedName) {
                return configClass.css(evaluatedName, configClass.tokens[evaluatedClass.token].value);
            });
            if (composition in config.screens) {
                productionClassesByType.screens[extractedClass.composition] =
                    productionClassesByType.screens[extractedClass.composition] || [];
                productionClassesByType.screens[extractedClass.composition].push(classEntry);
            }
            else {
                productionClassesByType.common[extractedClass.name] = classEntry;
            }
            if (evaluatedClass.variable) {
                var themes_1 = config.themes || {};
                var variableValue = evaluatedClass.variable.value;
                var originalValue_1 = evaluatedClass.variable.originalValue;
                var variables_1 = (variableValue.match(/var\(.*\)/) || []).map(function (varString) { return varString.replace(/var\(|\)/g, ''); });
                config.themeNames.forEach(function (theme) {
                    productionClassesByType.themeTokens[theme] = productionClassesByType.themeTokens[theme] || {};
                    variables_1.forEach(function (variable) {
                        var variableParts = variable.substr(2).split('-');
                        var variableKey = variableParts.shift();
                        var variableValueKey = variableParts.join('-');
                        productionClassesByType.themeTokens[theme][variable] = variable + ":" + themes_1[variableKey][variableValueKey][theme] + ";";
                        productionClassesByType.rootTokens[variable] = originalValue_1;
                    });
                });
            }
        });
    });
    return productionClassesByType;
};
exports.injectDevelopment = function (classCollection, classes, config) {
    return Object.keys(classCollection).reduce(function (aggr, composition) {
        return aggr.concat(Object.keys(classCollection[composition]).reduce(function (subAggr, id) {
            var extractedClass = classCollection[composition][id];
            var evaluatedClass = classes[extractedClass.id];
            var configClass = config.classnames[evaluatedClass.classname];
            var classEntry = exports.createClassEntry(extractedClass.name, extractedClass.decorators, function (evaluatedName) {
                return configClass.css(evaluatedName, configClass.tokens[evaluatedClass.token].value);
            });
            var css = '';
            if (composition in config.screens) {
                css += config.screens[extractedClass.composition](classEntry, exports.getScreens(config));
            }
            else {
                css = classEntry;
            }
            if (evaluatedClass.variable) {
                var themes_2 = config.themes || {};
                var variableValue = evaluatedClass.variable.value;
                var originalValue_2 = evaluatedClass.variable.originalValue;
                var variables = (variableValue.match(/var\(.*\)/) || []).map(function (varString) {
                    return varString.replace(/var\(|\)/g, '');
                });
                variables.forEach(function (variable) {
                    var variableParts = variable.substr(2).split('-');
                    var variableKey = variableParts.shift();
                    var variableValueKey = variableParts.join('-');
                    config.themeNames.forEach(function (theme) {
                        css += ":root{" + variable + ":" + originalValue_2 + ";}\n.themes-" + theme + "{" + variable + ":" + themes_2[variableKey][variableValueKey][theme] + ";}";
                    });
                });
            }
            return subAggr.concat([extractedClass.name, css]);
        }, []));
    }, []);
};
exports.negative = function (scale) {
    return Object.keys(scale)
        .filter(function (key) { return scale[key].value !== '0'; })
        .reduce(function (negativeScale, key) {
        var _a;
        return (tslib_1.__assign(tslib_1.__assign({}, negativeScale), (_a = {}, _a["NEGATIVE_" + key] = tslib_1.__assign(tslib_1.__assign({}, scale[key]), { value: exports.negateValue(scale[key].value) }), _a)));
    }, {});
};
exports.negateValue = function (value) {
    try {
        return reduce_css_calc_1.default("calc(" + value + " * -1)");
    }
    catch (e) {
        return value;
    }
};
exports.createName = function (decorators, name) {
    return [decorators.sort().join(':'), name]
        .filter(Boolean)
        .filter(function (i) { return i.length > 0; })
        .join(':');
};
exports.createExtractedClasses = function (extractedClasses) {
    return extractedClasses.reduce(function (aggr, extractedClass) {
        if (!aggr[extractedClass.composition]) {
            aggr[extractedClass.composition] = {};
        }
        aggr[extractedClass.composition][extractedClass.id] = extractedClass;
        return aggr;
    }, {});
};
exports.createProductionClassObjects = function (_a, classes, evaluatedProductionShortnames) {
    var composition = _a.composition, baseClass = _a.baseClass, token = _a.token, decorators = _a.decorators;
    var id = exports.camelToDash(baseClass) + "-" + token;
    if (id && !(id in classes)) {
        throw new Error("The token \"" + token + "\" does not exist on property \"" + baseClass + "\"");
    }
    if (classes[id].derived) {
        return classes[id].derived.reduce(function (aggr, key) {
            var derivedShortClassname = exports.generateCharsFromNumber(evaluatedProductionShortnames.classnames.indexOf(key) === -1
                ? evaluatedProductionShortnames.classnames.push(key)
                : evaluatedProductionShortnames.classnames.indexOf(key) + 1);
            var derivedShortToken = exports.generateCharsFromNumber(evaluatedProductionShortnames.tokens.indexOf(token) === -1
                ? evaluatedProductionShortnames.tokens.push(token)
                : evaluatedProductionShortnames.tokens.indexOf(token) + 1);
            var derivedShortDecorators = decorators
                .concat(composition === 'compose' ? [] : composition)
                .sort()
                .map(function (decorator) {
                return exports.generateCharsFromNumber(evaluatedProductionShortnames.decorators.indexOf(decorator) === -1
                    ? evaluatedProductionShortnames.decorators.push(decorator)
                    : evaluatedProductionShortnames.decorators.indexOf(decorator) + 1);
            })
                .join('');
            return aggr.concat({
                id: exports.camelToDash(key) + "-" + token,
                name: "" + (derivedShortDecorators.length ? derivedShortDecorators + "-" : '') + derivedShortClassname + "_" + derivedShortToken,
                decorators: decorators,
                composition: composition,
            });
        }, []);
    }
    var shortClassname = exports.generateCharsFromNumber(evaluatedProductionShortnames.classnames.indexOf(baseClass) === -1
        ? evaluatedProductionShortnames.classnames.push(baseClass)
        : evaluatedProductionShortnames.classnames.indexOf(baseClass) + 1);
    var shortToken = exports.generateCharsFromNumber(evaluatedProductionShortnames.tokens.indexOf(token) === -1
        ? evaluatedProductionShortnames.tokens.push(token)
        : evaluatedProductionShortnames.tokens.indexOf(token) + 1);
    var shortDecorators = decorators
        .concat(composition === 'compose' ? [] : composition)
        .sort()
        .map(function (decorator) {
        return exports.generateCharsFromNumber(evaluatedProductionShortnames.decorators.indexOf(decorator) === -1
            ? evaluatedProductionShortnames.decorators.push(decorator)
            : evaluatedProductionShortnames.decorators.indexOf(decorator) + 1);
    })
        .join('');
    return [
        {
            id: id,
            name: "" + (shortDecorators.length ? shortDecorators + "-" : '') + shortClassname + "_" + shortToken,
            decorators: decorators,
            composition: composition,
        },
    ];
};
exports.createClassObjects = function (_a, classes) {
    var composition = _a.composition, baseClass = _a.baseClass, token = _a.token, decorators = _a.decorators;
    var id = exports.camelToDash(baseClass) + "-" + token;
    if (id && !(id in classes)) {
        throw new Error("The token " + token + " does not exist on property " + baseClass);
    }
    if (classes[id].derived) {
        return classes[id].derived.reduce(function (aggr, key) {
            return aggr.concat({
                id: exports.camelToDash(key) + "-" + token,
                name: exports.createName(decorators.concat(composition === 'compose' ? [] : composition), exports.camelToDash(key) + "__" + token),
                decorators: decorators,
                composition: composition,
            });
        }, []);
    }
    return [
        {
            id: id,
            name: exports.createName(decorators.concat(composition === 'compose' ? [] : composition), exports.camelToDash(baseClass) + "__" + token),
            decorators: decorators,
            composition: composition,
        },
    ];
};
exports.generateCharsFromNumber = function (num) {
    var baseChar = 'A'.charCodeAt(0);
    var letters = '';
    do {
        num -= 1;
        letters = String.fromCharCode(baseChar + (num % 26)) + letters;
        num = (num / 26) >> 0;
    } while (num > 0);
    return letters;
};
exports.hyphenToCamelCase = function (str) {
    return str.replace(/-([a-z])/g, function (g) {
        return g[1].toUpperCase();
    });
};
//# sourceMappingURL=utils.js.map